+++
title = "The design of high performance mechatronics - third revised edition"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Reference Books]({{< relref "reference_books" >}}), [Dynamic Error Budgeting]({{< relref "dynamic_error_budgeting" >}})

Reference
: ([Schmidt, Schitter, and Rankers 2020](#orga3e0eb9))

Author(s)
: Schmidt, R. M., Schitter, G., & Rankers, A.

Year
: 2020

<a id="org6af53e1"></a>

{{< figure src="/ox-hugo/schmidt20_high_low_freq_regions.png" caption="Figure 1: Stabiliby condition and robustness of a feedback controlled system. The desired shape of these curves guide the control design by optimising the lvels and sloppes of the amplitude Bode-plot at low and high frequencies for suppression of the disturbances and of the base Bode-plot in the cross-over frequency region. This is called **loop shaping design**" >}}


## 2 Applied Physics in Mechatronic Systems {#2-applied-physics-in-mechatronic-systems}


### Introduction {#introduction}


### 2.1 Mechanics {#2-dot-1-mechanics}

> The core of a mechatronic system is its mechanical construction and in spite of many decade of excellent designs, optimizing the mechanical structure in strength, mass and endurance, the mechanical behavior will always remain the limiting factor of the performance of any mechatronic system.


#### 2.1.1 Coordinate Systems {#2-dot-1-dot-1-coordinate-systems}


##### 2.1.1.1 Cartesian Coordinate System {#2-dot-1-dot-1-dot-1-cartesian-coordinate-system}


##### 2.1.1.2 Generalised Coordinate System {#2-dot-1-dot-1-dot-2-generalised-coordinate-system}


##### 2.1.1.3 Modal Coordinate System {#2-dot-1-dot-1-dot-3-modal-coordinate-system}


#### 2.1.2 Force and Motion {#2-dot-1-dot-2-force-and-motion}

> _Statics_ deals with the stress levels that are present in the mechanical system when (quasi-)static forces are exerted on it.
> It analyses the linear and non-linear strain effects that are caused by elastic and plastic deformation under these stress levels.
>
> _Dynamics_ deals with the behaviour of the mechanical system under changing forces, while often the effects are linearised and limited to strain levels well below any irreversible plastic deformation.
> One should however be aware that another non-destructive source of non-linearity is found in a tried important field of mechanics, called _kinematics_.
> The relation between angles and positions is often non-linear in such a mechanism, because of the changing angles, and controlling these often requires special precautions to overcome the inherent non-linearities by linearisation around actual position and adapting the optimal settings of the controller to each position.


##### 2.1.2.1 Galilei and Newton's Laws of Motion {#2-dot-1-dot-2-dot-1-galilei-and-newton-s-laws-of-motion}


##### 2.1.2.2 Hooke's Law of Elasticity {#2-dot-1-dot-2-dot-2-hooke-s-law-of-elasticity}


##### 2.1.2.3 Lagrange Equations of Motion {#2-dot-1-dot-2-dot-3-lagrange-equations-of-motion}


### 2.2 Electricity and Magnetism {#2-dot-2-electricity-and-magnetism}


#### 2.2.1 Electric Field {#2-dot-2-dot-1-electric-field}

<a id="org8afa20a"></a>

{{< figure src="/ox-hugo/schmidt20_electrical_field.svg" caption="Figure 2: Charges have an electric field" >}}


##### 2.2.1.1 Potential Difference and Capacitance {#2-dot-2-dot-1-dot-1-potential-difference-and-capacitance}


##### 2.2.1.2 Electric Current in Conductive Material {#2-dot-2-dot-1-dot-2-electric-current-in-conductive-material}


#### 2.2.2 Magnetism and the Maxwell Equations {#2-dot-2-dot-2-magnetism-and-the-maxwell-equations}


#### 2.2.3 Electric Sources and Elements {#2-dot-2-dot-3-electric-sources-and-elements}


##### 2.2.3.1 Voltage Source {#2-dot-2-dot-3-dot-1-voltage-source}


##### 2.2.3.2 Summary on Voltage and Current {#2-dot-2-dot-3-dot-2-summary-on-voltage-and-current}


##### 2.2.3.3 Electric Power {#2-dot-2-dot-3-dot-3-electric-power}


##### 2.2.3.4 Ohm's Law {#2-dot-2-dot-3-dot-4-ohm-s-law}


##### 2.2.3.5 Practical Values and Summary {#2-dot-2-dot-3-dot-5-practical-values-and-summary}


### 2.3 Signal Theory and Wave Propagation {#2-dot-3-signal-theory-and-wave-propagation}


#### 2.3.1 The Concept of Frequency {#2-dot-3-dot-1-the-concept-of-frequency}


##### 2.3.1.1 Random Signals or Noise {#2-dot-3-dot-1-dot-1-random-signals-or-noise}


##### 2.3.1.2 Power of Alternating Signals {#2-dot-3-dot-1-dot-2-power-of-alternating-signals}


#### 2.3.2 Use of Complex Numbers {#2-dot-3-dot-2-use-of-complex-numbers}


##### 2.3.2.1 Dynamic Impedance and Ohm's Law {#2-dot-3-dot-2-dot-1-dynamic-impedance-and-ohm-s-law}


##### 2.3.2.2 Power in Dynamic Impedance {#2-dot-3-dot-2-dot-2-power-in-dynamic-impedance}


##### 2.3.2.3 Capacitive Impedance {#2-dot-3-dot-2-dot-3-capacitive-impedance}


##### 2.3.2.4 Inductive Impedance {#2-dot-3-dot-2-dot-4-inductive-impedance}


#### 2.3.3 Energy Propagation in Waves {#2-dot-3-dot-3-energy-propagation-in-waves}


##### 2.3.3.1 Mechanical Waves {#2-dot-3-dot-3-dot-1-mechanical-waves}


##### 2.3.3.2 Wave Equation {#2-dot-3-dot-3-dot-2-wave-equation}


##### 2.3.3.3 Electromagnetic Waves {#2-dot-3-dot-3-dot-3-electromagnetic-waves}


##### 2.3.3.4 Reflection of Waves {#2-dot-3-dot-3-dot-4-reflection-of-waves}


##### 2.3.3.5 Standing Waves {#2-dot-3-dot-3-dot-5-standing-waves}


#### 2.3.4 Fourier Decomposition of Alternating Signals {#2-dot-3-dot-4-fourier-decomposition-of-alternating-signals}


##### 2.3.4.1 Fourier in the frequency-domain {#2-dot-3-dot-4-dot-1-fourier-in-the-frequency-domain}


##### 2.3.4.2 Triangle Waveform {#2-dot-3-dot-4-dot-2-triangle-waveform}


##### 2.3.4.3 Sawtooth Waveform {#2-dot-3-dot-4-dot-3-sawtooth-waveform}


##### 2.3.4.4 Square Waveform {#2-dot-3-dot-4-dot-4-square-waveform}


##### 2.3.4.5 Non-Continuous Alternating Signals {#2-dot-3-dot-4-dot-5-non-continuous-alternating-signals}


### 2.4 Dynamic System Analysis and Modelling {#2-dot-4-dynamic-system-analysis-and-modelling}


#### 2.4.0.1 Laplace-Transform {#2-dot-4-dot-0-dot-1-laplace-transform}


##### 2.4.0.2 Poles and Zeros {#2-dot-4-dot-0-dot-2-poles-and-zeros}


##### 2.4.0.3 Order of a Dynamic System {#2-dot-4-dot-0-dot-3-order-of-a-dynamic-system}


#### 2.4.1 Dynamic Responses in the time-domain {#2-dot-4-dot-1-dynamic-responses-in-the-time-domain}


##### 2.4.1.1 Step Response {#2-dot-4-dot-1-dot-1-step-response}


##### 2.4.1.2 Impulse Response {#2-dot-4-dot-1-dot-2-impulse-response}


##### 2.4.1.3 Impulse Response and Pole Location {#2-dot-4-dot-1-dot-3-impulse-response-and-pole-location}


#### 2.4.2 Dynamic Responses in the frequency-domain {#2-dot-4-dot-2-dynamic-responses-in-the-frequency-domain}


##### 2.4.2.1 Frequency or Fourier-Domain Responses {#2-dot-4-dot-2-dot-1-frequency-or-fourier-domain-responses}


##### 2.4.2.2 Domain Notation of Dynamic Functions {#2-dot-4-dot-2-dot-2-domain-notation-of-dynamic-functions}


##### 2.4.2.3 Frequency Response Plots {#2-dot-4-dot-2-dot-3-frequency-response-plots}


##### 2.4.2.4 Bode Plot {#2-dot-4-dot-2-dot-4-bode-plot}


##### 2.4.2.5 Nyquist Plot {#2-dot-4-dot-2-dot-5-nyquist-plot}


##### 2.4.2.6 Limitation to LTI Systems {#2-dot-4-dot-2-dot-6-limitation-to-lti-systems}


## 3 Dynamics of Motion Systems {#3-dynamics-of-motion-systems}


### Introduction {#introduction}


### 3.1 Stiffness {#3-dot-1-stiffness}


#### 3.1.1 Importance of Stiffness for Precision {#3-dot-1-dot-1-importance-of-stiffness-for-precision}


#### 3.1.2 Active Stiffness {#3-dot-1-dot-2-active-stiffness}


### 3.2 Mass-Spring Systems with Damping {#3-dot-2-mass-spring-systems-with-damping}


#### 3.2.1 Dynamic Compliance {#3-dot-2-dot-1-dynamic-compliance}


##### 3.2.1.1 Compliance of a Spring {#3-dot-2-dot-1-dot-1-compliance-of-a-spring}


##### 3.2.1.2 Compliance of a Damper {#3-dot-2-dot-1-dot-2-compliance-of-a-damper}


##### 3.2.1.3 Compliance of a Body {#3-dot-2-dot-1-dot-3-compliance-of-a-body}


##### 3.2.1.4 Dynamic Stiffness {#3-dot-2-dot-1-dot-4-dynamic-stiffness}


##### 3.2.1.5 Lumping the Dynamic Elements {#3-dot-2-dot-1-dot-5-lumping-the-dynamic-elements}


#### 3.2.2 Transfer Function of Compliance {#3-dot-2-dot-2-transfer-function-of-compliance}


##### 3.2.2.1 Damped Mass-Spring System. {#3-dot-2-dot-2-dot-1-damped-mass-spring-system-dot}


##### 3.2.2.2 Magnitude {#3-dot-2-dot-2-dot-2-magnitude}


##### 3.2.2.3 Phase {#3-dot-2-dot-2-dot-3-phase}


##### 3.2.2.4 Bode Plot {#3-dot-2-dot-2-dot-4-bode-plot}


#### 3.2.3 Effects of Damping {#3-dot-2-dot-3-effects-of-damping}


##### 3.2.3.1 Damped Resonance and Aperiodic Damping {#3-dot-2-dot-3-dot-1-damped-resonance-and-aperiodic-damping}


##### 3.2.3.2 Poles and Critical Damping {#3-dot-2-dot-3-dot-2-poles-and-critical-damping}


##### 3.2.3.3 Quality-Factor Q and Energy in Resonance {#3-dot-2-dot-3-dot-3-quality-factor-q-and-energy-in-resonance}


#### 3.2.4 Transmissibility {#3-dot-2-dot-4-transmissibility}


#### 3.2.5 Fourth-Order Dynamic System {#3-dot-2-dot-5-fourth-order-dynamic-system}


##### 3.2.5.1 Analytical Description {#3-dot-2-dot-5-dot-1-analytical-description}


##### 3.2.5.2 Multiplicative Expression {#3-dot-2-dot-5-dot-2-multiplicative-expression}


##### 3.2.5.3 Effect of Different Mass Ratios {#3-dot-2-dot-5-dot-3-effect-of-different-mass-ratios}


### 3.3 Modal Decomposition {#3-dot-3-modal-decomposition}


#### 3.3.1 Eigenmodes of Two-Body Mass-Spring System {#3-dot-3-dot-1-eigenmodes-of-two-body-mass-spring-system}


#### 3.3.2 Theory of Modal Decomposition {#3-dot-3-dot-2-theory-of-modal-decomposition}


##### 3.3.2.1 Multi Degree of Freedom Equation of Motion {#3-dot-3-dot-2-dot-1-multi-degree-of-freedom-equation-of-motion}


##### 3.3.2.2 Eigenvalues and Eigenvectors {#3-dot-3-dot-2-dot-2-eigenvalues-and-eigenvectors}


##### 3.3.2.3 Modal Coordinates {#3-dot-3-dot-2-dot-3-modal-coordinates}


##### 3.3.2.4 Resulting Transfer Function {#3-dot-3-dot-2-dot-4-resulting-transfer-function}


#### 3.3.3 Graphical Representation of Mode-Shapes {#3-dot-3-dot-3-graphical-representation-of-mode-shapes}


##### 3.3.3.1 Traditional Representation {#3-dot-3-dot-3-dot-1-traditional-representation}


##### 3.3.3.2 Lever Representation {#3-dot-3-dot-3-dot-2-lever-representation}


##### 3.3.3.3 General System {#3-dot-3-dot-3-dot-3-general-system}


##### 3.3.3.4 User-Defined Physical DOF {#3-dot-3-dot-3-dot-4-user-defined-physical-dof}


#### 3.3.4 Physical Meaning of Modal Parameters {#3-dot-3-dot-4-physical-meaning-of-modal-parameters}


##### 3.3.4.1 Two-Body Mass-Spring System {#3-dot-3-dot-4-dot-1-two-body-mass-spring-system}


##### 3.3.4.2 Planar Flexibly Guided System {#3-dot-3-dot-4-dot-2-planar-flexibly-guided-system}


#### 3.3.5 A Pragmatic View on Sensitivity Analysis {#3-dot-3-dot-5-a-pragmatic-view-on-sensitivity-analysis}


##### 3.3.5.1 Example of Two Body Mass-Spring System {#3-dot-3-dot-5-dot-1-example-of-two-body-mass-spring-system}


##### 3.3.5.2 Example of Slightly Damped Resonance {#3-dot-3-dot-5-dot-2-example-of-slightly-damped-resonance}


#### 3.3.6 Suspension and Rigid-Body Modes {#3-dot-3-dot-6-suspension-and-rigid-body-modes}


##### 3.3.6.1 Quasi Rigid-Body Suspension mode {#3-dot-3-dot-6-dot-1-quasi-rigid-body-suspension-mode}


### 3.4 Mechanical Frequency Response {#3-dot-4-mechanical-frequency-response}


#### 3.4.1 Multiple eigenmodes {#3-dot-4-dot-1-multiple-eigenmodes}


#### 3.4.2 Characteristic Frequency Responses {#3-dot-4-dot-2-characteristic-frequency-responses}


##### 3.4.2.1 Frequency Response Type I {#3-dot-4-dot-2-dot-1-frequency-response-type-i}


##### 3.4.2.2 Frequency Response Type II {#3-dot-4-dot-2-dot-2-frequency-response-type-ii}


##### 3.4.2.3 Frequency Response Type III {#3-dot-4-dot-2-dot-3-frequency-response-type-iii}


##### 3.4.2.4 Frequency Response Type IV {#3-dot-4-dot-2-dot-4-frequency-response-type-iv}


#### 3.4.3 Example Systems with Type I/II/IV Response {#3-dot-4-dot-3-example-systems-with-type-i-ii-iv-response}


##### 3.4.3.1 Planar Moving Body on Compliant Spring {#3-dot-4-dot-3-dot-1-planar-moving-body-on-compliant-spring}


##### 3.4.3.2 H-drive Waferstage {#3-dot-4-dot-3-dot-2-h-drive-waferstage}


### 3.5 Summary on Dynamics {#3-dot-5-summary-on-dynamics}


## 4 Motion Control {#4-motion-control}


### Introduction {#introduction}


### 4.1 A Walk around the Control Loop {#4-dot-1-a-walk-around-the-control-loop}


#### 4.1.1 Poles and Zeros in Motion Control {#4-dot-1-dot-1-poles-and-zeros-in-motion-control}


#### 4.1.2 Overview Feedforward Control {#4-dot-1-dot-2-overview-feedforward-control}


##### 4.1.2.1 Summary of Feedforward Control {#4-dot-1-dot-2-dot-1-summary-of-feedforward-control}


#### 4.1.3 Overview Feedback Control {#4-dot-1-dot-3-overview-feedback-control}


##### 4.1.3.1 Summary of Feedback Control {#4-dot-1-dot-3-dot-1-summary-of-feedback-control}


### 4.2 Feedforward Control {#4-dot-2-feedforward-control}


#### 4.2.1 Model-Based Feedforward Control {#4-dot-2-dot-1-model-based-feedforward-control}


#### 4.2.2 Input-Shaping {#4-dot-2-dot-2-input-shaping}


#### 4.2.3 Adaptive Feedforward Control {#4-dot-2-dot-3-adaptive-feedforward-control}


#### 4.2.4 Trajectory Profile Generation {#4-dot-2-dot-4-trajectory-profile-generation}


### 4.3 Feedback Control {#4-dot-3-feedback-control}

> On might say that a high value of the unity-gain crossover frequency and corresponding high-frequency bandwidth limit is rather an unwanted side-effect of the required high loop-gain at lower frequencies, than a target for the design of a control system as such.


#### 4.3.1 Sensitivity to Input Signals {#4-dot-3-dot-1-sensitivity-to-input-signals}


##### 4.3.1.1 Sensitivity Functions {#4-dot-3-dot-1-dot-1-sensitivity-functions}


##### 4.3.1.2 Real Feedback Error Sensitivity {#4-dot-3-dot-1-dot-2-real-feedback-error-sensitivity}


#### 4.3.2 Stability and Robustness in Feedback Control {#4-dot-3-dot-2-stability-and-robustness-in-feedback-control}


##### 4.3.2.1 Stability margins {#4-dot-3-dot-2-dot-1-stability-margins}


### 4.4 PID Feedback Control {#4-dot-4-pid-feedback-control}


#### 4.4.1 PID-Control of a Compact-Disc Player {#4-dot-4-dot-1-pid-control-of-a-compact-disc-player}


##### 4.4.1.1 Relevant Sensitivity Functions {#4-dot-4-dot-1-dot-1-relevant-sensitivity-functions}


##### 4.4.1.2 Proportional Feedback {#4-dot-4-dot-1-dot-2-proportional-feedback}


##### 4.4.1.3 Proportional-Differential Feedback {#4-dot-4-dot-1-dot-3-proportional-differential-feedback}


##### 4.4.1.4 Limiting the Differentiating Action {#4-dot-4-dot-1-dot-4-limiting-the-differentiating-action}


##### 4.4.1.5 Adding I-Control {#4-dot-4-dot-1-dot-5-adding-i-control}


#### 4.4.2 PID-Control of a Spring Supported Mass {#4-dot-4-dot-2-pid-control-of-a-spring-supported-mass}


##### 4.4.2.1 P-Control {#4-dot-4-dot-2-dot-1-p-control}


##### 4.4.2.2 D-Control {#4-dot-4-dot-2-dot-2-d-control}


##### 4.4.2.3 I-Control {#4-dot-4-dot-2-dot-3-i-control}


##### 4.4.2.4 Sensitivity Function Graphs {#4-dot-4-dot-2-dot-4-sensitivity-function-graphs}


#### 4.4.3 Limitations and Side Effects of PID-Feedback Control {#4-dot-4-dot-3-limitations-and-side-effects-of-pid-feedback-control}


##### 4.4.3.1 Increased Sensitivity, the Waterbed Effect {#4-dot-4-dot-3-dot-1-increased-sensitivity-the-waterbed-effect}


##### 4.4.3.2 Integrator Wind-Up and Delays {#4-dot-4-dot-3-dot-2-integrator-wind-up-and-delays}


#### 4.4.4 PID-Control of a Fourth-Order Dynamic System {#4-dot-4-dot-4-pid-control-of-a-fourth-order-dynamic-system}


##### 4.4.4.1 Controlling a Type III Dynamic System {#4-dot-4-dot-4-dot-1-controlling-a-type-iii-dynamic-system}


##### 4.4.4.2 Passive Damping {#4-dot-4-dot-4-dot-2-passive-damping}


##### 4.4.4.3 Shifting the Phase {#4-dot-4-dot-4-dot-3-shifting-the-phase}


#### 4.4.5 PID-Control of a Piezoelectric Actuator {#4-dot-4-dot-5-pid-control-of-a-piezoelectric-actuator}


##### 4.4.5.1 Creating a Fourth-Order System {#4-dot-4-dot-5-dot-1-creating-a-fourth-order-system}


#### 4.4.6 PID-Control of a Magnetic Bearing {#4-dot-4-dot-6-pid-control-of-a-magnetic-bearing}


##### 4.4.6.1 Frequency Response {#4-dot-4-dot-6-dot-1-frequency-response}


##### 4.4.6.2 Positive Stiffness by P-Control {#4-dot-4-dot-6-dot-2-positive-stiffness-by-p-control}


##### 4.4.6.3 D-Control and Pole Placement {#4-dot-4-dot-6-dot-3-d-control-and-pole-placement}


##### 4.4.6.4 I-control for Reduced Sensitivity {#4-dot-4-dot-6-dot-4-i-control-for-reduced-sensitivity}


#### 4.4.7 Optimisation by Loop-Shaping Design {#4-dot-4-dot-7-optimisation-by-loop-shaping-design}


##### 4.4.7.1 Optimal Value of Alpha {#4-dot-4-dot-7-dot-1-optimal-value-of-alpha}


##### 4.4.7.2 Additional Low-Pass Filtering {#4-dot-4-dot-7-dot-2-additional-low-pass-filtering}


##### 4.4.7.3 Notching Filters {#4-dot-4-dot-7-dot-3-notching-filters}


##### 4.4.7.4 Peaking and Shelving Filters {#4-dot-4-dot-7-dot-4-peaking-and-shelving-filters}


#### 4.4.8 Design Steps for PID-control {#4-dot-4-dot-8-design-steps-for-pid-control}


### 4.5 Digital Signal Processing - The Z-Domain {#4-dot-5-digital-signal-processing-the-z-domain}


#### 4.5.1 Continuous Time versus Discrete Time {#4-dot-5-dot-1-continuous-time-versus-discrete-time}


#### 4.5.2 Sampling of Continuous Signals {#4-dot-5-dot-2-sampling-of-continuous-signals}


#### 4.5.3 Digital Number Representation {#4-dot-5-dot-3-digital-number-representation}


##### 4.5.3.1 Fixed Point Arithmetic {#4-dot-5-dot-3-dot-1-fixed-point-arithmetic}


##### 4.5.3.2 Floating Point Arithmetic {#4-dot-5-dot-3-dot-2-floating-point-arithmetic}


#### 4.5.4 Digital Filter Theory {#4-dot-5-dot-4-digital-filter-theory}


##### 4.5.4.1 Z-Transform and Difference Equations {#4-dot-5-dot-4-dot-1-z-transform-and-difference-equations}


#### 4.5.5 Finite Impulse Response (FIR) Filter {#4-dot-5-dot-5-finite-impulse-response--fir--filter}


#### 4.5.6 Infinite Impulse Response (IIR) Filter {#4-dot-5-dot-6-infinite-impulse-response--iir--filter}


#### 4.5.7 Converting Continuous to Discrete-Time Filters {#4-dot-5-dot-7-converting-continuous-to-discrete-time-filters}


### 4.6 State-Space Feedback Control {#4-dot-6-state-space-feedback-control}


#### 4.6.1 State-Space in Relation to Motion Control {#4-dot-6-dot-1-state-space-in-relation-to-motion-control}


##### 4.6.1.1 Mechanical Dynamic System in State-Space {#4-dot-6-dot-1-dot-1-mechanical-dynamic-system-in-state-space}


##### 4.6.1.2 PID-Control Feedback in State-Space {#4-dot-6-dot-1-dot-2-pid-control-feedback-in-state-space}


#### 4.6.2 State Feedback {#4-dot-6-dot-2-state-feedback}


##### 4.6.2.1 System Identification {#4-dot-6-dot-2-dot-1-system-identification}


##### 4.6.2.2 State Estimation {#4-dot-6-dot-2-dot-2-state-estimation}


##### 4.6.2.3 Additional Remarks on State-Space Control {#4-dot-6-dot-2-dot-3-additional-remarks-on-state-space-control}


### 4.7 Conclusion on Motion Control {#4-dot-7-conclusion-on-motion-control}


## 5 Electromechanic Actuators {#5-electromechanic-actuators}


### Introduction {#introduction}


### 5.1 Electromagnetics {#5-dot-1-electromagnetics}


#### 5.1.1 Hopkinson's Law {#5-dot-1-dot-1-hopkinson-s-law}


##### 5.1.1.1 Practical Aspects of Hopkinson's Law {#5-dot-1-dot-1-dot-1-practical-aspects-of-hopkinson-s-law}


##### 5.1.1.2 Magnetic Energy {#5-dot-1-dot-1-dot-2-magnetic-energy}


#### 5.1.2 Ferromagnetic Materials {#5-dot-1-dot-2-ferromagnetic-materials}


##### 5.1.2.1 Coil with Ferromagnetic Yoke {#5-dot-1-dot-2-dot-1-coil-with-ferromagnetic-yoke}


##### 5.1.2.2 Magnetisation Curve {#5-dot-1-dot-2-dot-2-magnetisation-curve}


##### 5.1.2.3 Permanent Magnets {#5-dot-1-dot-2-dot-3-permanent-magnets}


#### 5.1.3 Creating a Magnetic Field in an Air-Gap {#5-dot-1-dot-3-creating-a-magnetic-field-in-an-air-gap}


##### 5.1.3.1 Optimal Use of Permanent Magnet Material {#5-dot-1-dot-3-dot-1-optimal-use-of-permanent-magnet-material}


##### 5.1.3.2 Flat Magnets Reduce Fringing Flux {#5-dot-1-dot-3-dot-2-flat-magnets-reduce-fringing-flux}


##### 5.1.3.3 Low Cost Loudspeaker Magnet {#5-dot-1-dot-3-dot-3-low-cost-loudspeaker-magnet}


### 5.2 Lorentz Actuator {#5-dot-2-lorentz-actuator}


#### 5.2.1 Lorentz Force {#5-dot-2-dot-1-lorentz-force}


##### 5.2.1.1 Force from Flux-Linkage {#5-dot-2-dot-1-dot-1-force-from-flux-linkage}


#### 5.2.2 The Lorentz actuator as a Generator {#5-dot-2-dot-2-the-lorentz-actuator-as-a-generator}


#### 5.2.3 Improving the Force of a Lorentz Actuator {#5-dot-2-dot-3-improving-the-force-of-a-lorentz-actuator}


##### 5.2.3.1 The Moving-Coil Loudspeaker Actuator {#5-dot-2-dot-3-dot-1-the-moving-coil-loudspeaker-actuator}


#### 5.2.4 Position Dependency of the Lorentz Force {#5-dot-2-dot-4-position-dependency-of-the-lorentz-force}


##### 5.2.4.1 Over-Hung and Under-Hung Coil {#5-dot-2-dot-4-dot-1-over-hung-and-under-hung-coil}


#### 5.2.5 Electronic Commutation {#5-dot-2-dot-5-electronic-commutation}


##### 5.2.5.1 Three-Phase Electronic Control {#5-dot-2-dot-5-dot-1-three-phase-electronic-control}


#### 5.2.6 Figures of Merit of a Lorentz Actuator {#5-dot-2-dot-6-figures-of-merit-of-a-lorentz-actuator}


### 5.3 Variable Reluctance Actuation {#5-dot-3-variable-reluctance-actuation}


#### 5.3.1 Reluctance Force in Lorentz Actuator {#5-dot-3-dot-1-reluctance-force-in-lorentz-actuator}


##### 5.3.1.1 Eddy-Current Ring {#5-dot-3-dot-1-dot-1-eddy-current-ring}


##### 5.3.1.2 Ironless Stator {#5-dot-3-dot-1-dot-2-ironless-stator}


#### 5.3.2 Analytical Derivation of Reluctance Force {#5-dot-3-dot-2-analytical-derivation-of-reluctance-force}


#### 5.3.3 Variable Reluctance Actuator. {#5-dot-3-dot-3-variable-reluctance-actuator-dot}


##### 5.3.3.1 Electromagnetic Relay {#5-dot-3-dot-3-dot-1-electromagnetic-relay}


##### 5.3.3.2 Magnetic Attraction Force {#5-dot-3-dot-3-dot-2-magnetic-attraction-force}


#### 5.3.4 Permanent Magnet Biased Reluctance Actuator {#5-dot-3-dot-4-permanent-magnet-biased-reluctance-actuator}


##### 5.3.4.1 Double Variable Reluctance Actuator {#5-dot-3-dot-4-dot-1-double-variable-reluctance-actuator}


##### 5.3.4.2 Constant Common Flux {#5-dot-3-dot-4-dot-2-constant-common-flux}


##### 5.3.4.3 Combining two Sources of Magnetic Flux {#5-dot-3-dot-4-dot-3-combining-two-sources-of-magnetic-flux}


##### 5.3.4.4 Hybrid Force Calculation {#5-dot-3-dot-4-dot-4-hybrid-force-calculation}


##### 5.3.4.5 Magnetic Bearings {#5-dot-3-dot-4-dot-5-magnetic-bearings}


#### 5.3.5 Active Linearisation of the Reluctance Force {#5-dot-3-dot-5-active-linearisation-of-the-reluctance-force}


### 5.4 Application of Electromagnetic Actuators {#5-dot-4-application-of-electromagnetic-actuators}


#### 5.4.1 Electrical Interface Properties {#5-dot-4-dot-1-electrical-interface-properties}


##### 5.4.1.1 Dynamic Effects of Self-Inductance {#5-dot-4-dot-1-dot-1-dynamic-effects-of-self-inductance}


##### 5.4.1.2 Limitation of the \`\`Jerk'' {#5-dot-4-dot-1-dot-2-limitation-of-the-jerk}


##### 5.4.1.3 Electromagnetic Damping {#5-dot-4-dot-1-dot-3-electromagnetic-damping}


#### 5.4.2 Comparison of three Electromagnetic Actuators {#5-dot-4-dot-2-comparison-of-three-electromagnetic-actuators}


##### 5.4.2.1 Force-Constants {#5-dot-4-dot-2-dot-1-force-constants}


##### 5.4.2.2 Figures of Merit Including Mass {#5-dot-4-dot-2-dot-2-figures-of-merit-including-mass}


##### 5.4.2.3 Stiffness {#5-dot-4-dot-2-dot-3-stiffness}


##### 5.4.2.4 Repeatability and Predictability {#5-dot-4-dot-2-dot-4-repeatability-and-predictability}


##### 5.4.2.5 Dynamic Effects on the Control Loop {#5-dot-4-dot-2-dot-5-dynamic-effects-on-the-control-loop}


### 5.5 Piezoelectric Actuators {#5-dot-5-piezoelectric-actuators}


#### 5.5.1 Piezoelectricity {#5-dot-5-dot-1-piezoelectricity}


##### 5.5.1.1 Poling {#5-dot-5-dot-1-dot-1-poling}


##### 5.5.1.2 Tapping the Bound Charge by Electrodes {#5-dot-5-dot-1-dot-2-tapping-the-bound-charge-by-electrodes}


#### 5.5.2 Transducer Models {#5-dot-5-dot-2-transducer-models}


#### 5.5.3 Nonlinearity of Piezoelectric Actuators {#5-dot-5-dot-3-nonlinearity-of-piezoelectric-actuators}


##### 5.5.3.1 Creep {#5-dot-5-dot-3-dot-1-creep}


##### 5.5.3.2 Hysteresis {#5-dot-5-dot-3-dot-2-hysteresis}


##### 5.5.3.3 Aging {#5-dot-5-dot-3-dot-3-aging}


#### 5.5.4 Mechanical Considerations {#5-dot-5-dot-4-mechanical-considerations}


##### 5.5.4.1 Piezoelectric Actuator Stiffness {#5-dot-5-dot-4-dot-1-piezoelectric-actuator-stiffness}


##### 5.5.4.2 Actuator Types {#5-dot-5-dot-4-dot-2-actuator-types}


##### 5.5.4.3 Long Range Actuation by Friction {#5-dot-5-dot-4-dot-3-long-range-actuation-by-friction}


##### 5.5.4.4 Actuator Integration {#5-dot-5-dot-4-dot-4-actuator-integration}


##### 5.5.4.5 Mechanical Amplification {#5-dot-5-dot-4-dot-5-mechanical-amplification}


##### 5.5.4.6 Multiple Motion Directions by Stacking {#5-dot-5-dot-4-dot-6-multiple-motion-directions-by-stacking}


#### 5.5.5 Electrical Considerations {#5-dot-5-dot-5-electrical-considerations}


##### 5.5.5.1 Charge vs. Voltage Control {#5-dot-5-dot-5-dot-1-charge-vs-dot-voltage-control}


##### 5.5.5.2 Self-Sensing Actuation {#5-dot-5-dot-5-dot-2-self-sensing-actuation}


### 5.6 Choosing the right Actuator Type {#5-dot-6-choosing-the-right-actuator-type}


## 6 Analogue Electronics in Mechatronic Systems {#6-analogue-electronics-in-mechatronic-systems}


### Introduction {#introduction}


### 6.1 Passive Linear Electronics {#6-dot-1-passive-linear-electronics}


#### 6.1.1 Network Theory and Laws {#6-dot-1-dot-1-network-theory-and-laws}


##### 6.1.1.1 Voltage Source {#6-dot-1-dot-1-dot-1-voltage-source}


##### 6.1.1.2 Current Source {#6-dot-1-dot-1-dot-2-current-source}


##### 6.1.1.3 Theorem of Norton and Thevenin {#6-dot-1-dot-1-dot-3-theorem-of-norton-and-thevenin}


##### 6.1.1.4 Kirchhoff's Laws {#6-dot-1-dot-1-dot-4-kirchhoff-s-laws}


##### 6.1.1.5 Impedances in Series or Parallel {#6-dot-1-dot-1-dot-5-impedances-in-series-or-parallel}


##### 6.1.1.6 Voltage Divider {#6-dot-1-dot-1-dot-6-voltage-divider}


##### 6.1.1.7 Maximum Power of a Real Voltage Source {#6-dot-1-dot-1-dot-7-maximum-power-of-a-real-voltage-source}


#### 6.1.2 Impedances in Electronic Circuits {#6-dot-1-dot-2-impedances-in-electronic-circuits}


##### 6.1.2.1 Resistors {#6-dot-1-dot-2-dot-1-resistors}


##### 6.1.2.2 Capacitors {#6-dot-1-dot-2-dot-2-capacitors}


##### 6.1.2.3 Inductors {#6-dot-1-dot-2-dot-3-inductors}


#### 6.1.3 Passive Filters {#6-dot-1-dot-3-passive-filters}


##### 6.1.3.1 Passive First-Order RC-Filters {#6-dot-1-dot-3-dot-1-passive-first-order-rc-filters}


##### 6.1.3.2 Passive Higher-Order RC-Filters {#6-dot-1-dot-3-dot-2-passive-higher-order-rc-filters}


##### 6.1.3.3 Passive LCR-Filters {#6-dot-1-dot-3-dot-3-passive-lcr-filters}


#### 6.1.4 Mechanical-Electrical Dynamic Analogy {#6-dot-1-dot-4-mechanical-electrical-dynamic-analogy}


### 6.2 Semiconductors and Active Electronics {#6-dot-2-semiconductors-and-active-electronics}


#### 6.2.1 Basic Discrete Semiconductors {#6-dot-2-dot-1-basic-discrete-semiconductors}


##### 6.2.1.1 Semiconductor Diode {#6-dot-2-dot-1-dot-1-semiconductor-diode}


##### 6.2.1.2 Bipolar Transistors {#6-dot-2-dot-1-dot-2-bipolar-transistors}


##### 6.2.1.3 MOSFET {#6-dot-2-dot-1-dot-3-mosfet}


##### 6.2.1.4 Other Discrete Semiconductors {#6-dot-2-dot-1-dot-4-other-discrete-semiconductors}


#### 6.2.2 Single Transistor Linear Amplifiers {#6-dot-2-dot-2-single-transistor-linear-amplifiers}


##### 6.2.2.1 Emitter Follower {#6-dot-2-dot-2-dot-1-emitter-follower}


##### 6.2.2.2 Voltage Amplifier {#6-dot-2-dot-2-dot-2-voltage-amplifier}


##### 6.2.2.3 Differential Amplifier {#6-dot-2-dot-2-dot-3-differential-amplifier}


#### 6.2.3 Operational Amplifier {#6-dot-2-dot-3-operational-amplifier}


##### 6.2.3.1 Basic Operational Amplifier Design {#6-dot-2-dot-3-dot-1-basic-operational-amplifier-design}


##### 6.2.3.2 Operational Amplifier with Feedback {#6-dot-2-dot-3-dot-2-operational-amplifier-with-feedback}


#### 6.2.4 Linear Amplifiers with Operational Amplifiers {#6-dot-2-dot-4-linear-amplifiers-with-operational-amplifiers}


##### 6.2.4.1 Design Rules {#6-dot-2-dot-4-dot-1-design-rules}


##### 6.2.4.2 Non-Inverting Amplifier {#6-dot-2-dot-4-dot-2-non-inverting-amplifier}


##### 6.2.4.3 Inverting Amplifier {#6-dot-2-dot-4-dot-3-inverting-amplifier}


##### 6.2.4.4 Adding and Subtracting Signals {#6-dot-2-dot-4-dot-4-adding-and-subtracting-signals}


##### 6.2.4.5 Transimpedance Amplifier {#6-dot-2-dot-4-dot-5-transimpedance-amplifier}


##### 6.2.4.6 Transconductance Amplifier {#6-dot-2-dot-4-dot-6-transconductance-amplifier}


#### 6.2.5 Active Electronic Filters {#6-dot-2-dot-5-active-electronic-filters}


##### 6.2.5.1 Integrator and First-Order Low-Pass {#6-dot-2-dot-5-dot-1-integrator-and-first-order-low-pass}


##### 6.2.5.2 Differentiator and First-Order High-Pass {#6-dot-2-dot-5-dot-2-differentiator-and-first-order-high-pass}


#### 6.2.6 Analogue PID-Controller {#6-dot-2-dot-6-analogue-pid-controller}


##### 6.2.6.1 PID Transfer Function {#6-dot-2-dot-6-dot-1-pid-transfer-function}


##### 6.2.6.2 PID Control Gains {#6-dot-2-dot-6-dot-2-pid-control-gains}


##### 6.2.6.3 High-Speed PID-Control {#6-dot-2-dot-6-dot-3-high-speed-pid-control}


#### 6.2.7 Higher-order Electronic Filters {#6-dot-2-dot-7-higher-order-electronic-filters}


##### 6.2.7.1 Second-Order Low-Pass Filter {#6-dot-2-dot-7-dot-1-second-order-low-pass-filter}


##### 6.2.7.2 Different Types of Active Filters {#6-dot-2-dot-7-dot-2-different-types-of-active-filters}


#### 6.2.8 Ideal and Real Operational Amplifiers {#6-dot-2-dot-8-ideal-and-real-operational-amplifiers}


##### 6.2.8.1 Open-Loop Voltage Gain {#6-dot-2-dot-8-dot-1-open-loop-voltage-gain}


##### 6.2.8.2 Dynamic Limitations {#6-dot-2-dot-8-dot-2-dynamic-limitations}


##### 6.2.8.3 Input Related Limitations {#6-dot-2-dot-8-dot-3-input-related-limitations}


##### 6.2.8.4 Power Supply and Output Limitations {#6-dot-2-dot-8-dot-4-power-supply-and-output-limitations}


#### 6.2.9 Closing Remarks on Low-Power Electronics {#6-dot-2-dot-9-closing-remarks-on-low-power-electronics}


### 6.3 Power Amplifiers for Motion Control {#6-dot-3-power-amplifiers-for-motion-control}


#### 6.3.1 Required Properties for Actuator Drive {#6-dot-3-dot-1-required-properties-for-actuator-drive}


##### 6.3.1.1 Power Delivery Capability {#6-dot-3-dot-1-dot-1-power-delivery-capability}


##### 6.3.1.2 Dynamic Properties {#6-dot-3-dot-1-dot-2-dynamic-properties}


##### 6.3.1.3 Linearity, Freedom of Distortion {#6-dot-3-dot-1-dot-3-linearity-freedom-of-distortion}


##### 6.3.1.4 Voltage or Current Drive {#6-dot-3-dot-1-dot-4-voltage-or-current-drive}


##### 6.3.1.5 Efficiency {#6-dot-3-dot-1-dot-5-efficiency}


##### 6.3.1.6 Four-Quadrant Operation {#6-dot-3-dot-1-dot-6-four-quadrant-operation}


##### 6.3.1.7 Preferred Power Amplifier Principle {#6-dot-3-dot-1-dot-7-preferred-power-amplifier-principle}


#### 6.3.2 Switched-Mode Power Amplifiers {#6-dot-3-dot-2-switched-mode-power-amplifiers}


##### 6.3.2.1 Power MOSFET, a Fast High-Power Switch {#6-dot-3-dot-2-dot-1-power-mosfet-a-fast-high-power-switch}


##### 6.3.2.2 Switching Sequence Generation {#6-dot-3-dot-2-dot-2-switching-sequence-generation}


##### 6.3.2.3 Voltage Drive Amplifier {#6-dot-3-dot-2-dot-3-voltage-drive-amplifier}


##### 6.3.2.4 Energy Flow in the Power Output Stage {#6-dot-3-dot-2-dot-4-energy-flow-in-the-power-output-stage}


##### 6.3.2.5 Intermediate Conclusions and Other Issues {#6-dot-3-dot-2-dot-5-intermediate-conclusions-and-other-issues}


##### 6.3.2.6 Driving the Power MOSFETs {#6-dot-3-dot-2-dot-6-driving-the-power-mosfets}


##### 6.3.2.7 Charge Pumping {#6-dot-3-dot-2-dot-7-charge-pumping}


##### 6.3.2.8 H-Bridge Configuration {#6-dot-3-dot-2-dot-8-h-bridge-configuration}


##### 6.3.2.9 Output Filter {#6-dot-3-dot-2-dot-9-output-filter}


#### 6.3.3 Resonant-Mode Power Amplifiers {#6-dot-3-dot-3-resonant-mode-power-amplifiers}


##### 6.3.3.1 Switching Sequence of the Output Stage {#6-dot-3-dot-3-dot-1-switching-sequence-of-the-output-stage}


##### 6.3.3.2 Lossless Current Sensing {#6-dot-3-dot-3-dot-2-lossless-current-sensing}


#### 6.3.4 Three-Phase Amplifiers {#6-dot-3-dot-4-three-phase-amplifiers}


##### 6.3.4.1 Concept of Three-Phase Amplifier {#6-dot-3-dot-4-dot-1-concept-of-three-phase-amplifier}


##### 6.3.4.2 Three-Phase Switching Power Stages {#6-dot-3-dot-4-dot-2-three-phase-switching-power-stages}


#### 6.3.5 Some Last Remarks on Power Electronics {#6-dot-3-dot-5-some-last-remarks-on-power-electronics}


## 7 Optics in Mechatronic Systems {#7-optics-in-mechatronic-systems}


### Introduction {#introduction}


### 7.1 Properties of Light and Light Sources {#7-dot-1-properties-of-light-and-light-sources}


#### 7.1.1 Light Generation by Thermal Radiation {#7-dot-1-dot-1-light-generation-by-thermal-radiation}


#### 7.1.2 Photons by Electron Energy State Variation {#7-dot-1-dot-2-photons-by-electron-energy-state-variation}


##### 7.1.2.1 Light Emitting Diodes {#7-dot-1-dot-2-dot-1-light-emitting-diodes}


##### 7.1.2.2 Laser as an Ideal Light Source {#7-dot-1-dot-2-dot-2-laser-as-an-ideal-light-source}


#### 7.1.3 Useful Power from a Light Source {#7-dot-1-dot-3-useful-power-from-a-light-source}


##### 7.1.3.1 Radiant Emittance and Irradiance {#7-dot-1-dot-3-dot-1-radiant-emittance-and-irradiance}


##### 7.1.3.2 Radiance {#7-dot-1-dot-3-dot-2-radiance}


##### 7.1.3.3 Etendue {#7-dot-1-dot-3-dot-3-etendue}


### 7.2 Reflection and Refraction {#7-dot-2-reflection-and-refraction}


#### 7.2.1 Reflection and Refraction according to the Least Time {#7-dot-2-dot-1-reflection-and-refraction-according-to-the-least-time}


##### 7.2.1.1 Partial Reflection and Refraction {#7-dot-2-dot-1-dot-1-partial-reflection-and-refraction}


#### 7.2.2 Concept of Wavefront {#7-dot-2-dot-2-concept-of-wavefront}


##### 7.2.2.1 A Wavefront is Not Real {#7-dot-2-dot-2-dot-1-a-wavefront-is-not-real}


### 7.3 Geometric Optics {#7-dot-3-geometric-optics}


#### 7.3.1 Imaging with Refractive Lens Elements {#7-dot-3-dot-1-imaging-with-refractive-lens-elements}


##### 7.3.1.1 Sign Conventions {#7-dot-3-dot-1-dot-1-sign-conventions}


##### 7.3.1.2 Real Lens Elements {#7-dot-3-dot-1-dot-2-real-lens-elements}


##### 7.3.1.3 Magnification {#7-dot-3-dot-1-dot-3-magnification}


#### 7.3.2 Aberrations {#7-dot-3-dot-2-aberrations}


##### 7.3.2.1 Spherical Aberration {#7-dot-3-dot-2-dot-1-spherical-aberration}


##### 7.3.2.2 Astigmatism {#7-dot-3-dot-2-dot-2-astigmatism}


##### 7.3.2.3 Coma {#7-dot-3-dot-2-dot-3-coma}


##### 7.3.2.4 Geometric and Chromatic Aberrations {#7-dot-3-dot-2-dot-4-geometric-and-chromatic-aberrations}


#### 7.3.3 Combining Multiple Optical Elements {#7-dot-3-dot-3-combining-multiple-optical-elements}


##### 7.3.3.1 Combining Two Positive Lenses {#7-dot-3-dot-3-dot-1-combining-two-positive-lenses}


#### 7.3.4 Aperture Stop and Pupil {#7-dot-3-dot-4-aperture-stop-and-pupil}


#### 7.3.5 Telecentricity {#7-dot-3-dot-5-telecentricity}


##### 7.3.5.1 Pupil, Aperture and Lens Dimensions {#7-dot-3-dot-5-dot-1-pupil-aperture-and-lens-dimensions}


##### 7.3.5.2 Practical Applications and Constraints {#7-dot-3-dot-5-dot-2-practical-applications-and-constraints}


### 7.4 Physical Optics {#7-dot-4-physical-optics}


#### 7.4.1 Polarisation {#7-dot-4-dot-1-polarisation}


##### 7.4.1.1 Birefringence {#7-dot-4-dot-1-dot-1-birefringence}


#### 7.4.2 Interference {#7-dot-4-dot-2-interference}


##### 7.4.2.1 Fabry-Perot Interferometer {#7-dot-4-dot-2-dot-1-fabry-perot-interferometer}


#### 7.4.3 Diffraction {#7-dot-4-dot-3-diffraction}


##### 7.4.3.1 Amplitude gratings {#7-dot-4-dot-3-dot-1-amplitude-gratings}


##### 7.4.3.2 Phase Gratings {#7-dot-4-dot-3-dot-2-phase-gratings}


##### 7.4.3.3 Direction of the Incoming Light {#7-dot-4-dot-3-dot-3-direction-of-the-incoming-light}


#### 7.4.4 Imaging Quality based on Diffraction {#7-dot-4-dot-4-imaging-quality-based-on-diffraction}


##### 7.4.4.1 Numerical Aperture and f-Number {#7-dot-4-dot-4-dot-1-numerical-aperture-and-f-number}


##### 7.4.4.2 Depth of Focus {#7-dot-4-dot-4-dot-2-depth-of-focus}


### 7.5 Adaptive Optics {#7-dot-5-adaptive-optics}


#### 7.5.1 Thermal Effects in Optical Imaging Systems {#7-dot-5-dot-1-thermal-effects-in-optical-imaging-systems}


#### 7.5.2 Correcting the Wavefront {#7-dot-5-dot-2-correcting-the-wavefront}


##### 7.5.2.1 Zernike Polynomials {#7-dot-5-dot-2-dot-1-zernike-polynomials}


##### 7.5.2.2 Correcting Zernikes by Adaptive Optics {#7-dot-5-dot-2-dot-2-correcting-zernikes-by-adaptive-optics}


#### 7.5.3 Adaptive Optics Principle of Operation {#7-dot-5-dot-3-adaptive-optics-principle-of-operation}


##### 7.5.3.1 Active Mirrors {#7-dot-5-dot-3-dot-1-active-mirrors}


## 8 Measurement in Mechatronic Systems {#8-measurement-in-mechatronic-systems}


### Introduction {#introduction}


#### 8.0.1 Measurement Systems {#8-dot-0-dot-1-measurement-systems}


#### 8.0.2 Errors in Measurement Systems, Uncertainty {#8-dot-0-dot-2-errors-in-measurement-systems-uncertainty}


##### 8.0.2.1 Uncertainty in Traceable Measurements {#8-dot-0-dot-2-dot-1-uncertainty-in-traceable-measurements}


#### 8.0.3 Functional Model of a Measurement System Element {#8-dot-0-dot-3-functional-model-of-a-measurement-system-element}


### 8.1 Dynamic Error Budgeting {#8-dot-1-dynamic-error-budgeting}


#### 8.1.1 Error Statistics in Repeated Measurements {#8-dot-1-dot-1-error-statistics-in-repeated-measurements}


#### 8.1.2 The Normal Distribution {#8-dot-1-dot-2-the-normal-distribution}


#### 8.1.3 Combining Different Error Sources {#8-dot-1-dot-3-combining-different-error-sources}


#### 8.1.4 Power Spectral Density and Cumulative Power {#8-dot-1-dot-4-power-spectral-density-and-cumulative-power}


#### 8.1.5 Do not use the Cumulative Amplitude Spectrum! {#8-dot-1-dot-5-do-not-use-the-cumulative-amplitude-spectrum}


#### 8.1.6 Variations in Dynamic Error Budgeting {#8-dot-1-dot-6-variations-in-dynamic-error-budgeting}


#### 8.1.7 Sources of Noise and Disturbances {#8-dot-1-dot-7-sources-of-noise-and-disturbances}


##### 8.1.7.1 Mechanical Noise {#8-dot-1-dot-7-dot-1-mechanical-noise}


##### 8.1.7.2 Electronic Noise {#8-dot-1-dot-7-dot-2-electronic-noise}


### 8.2 Sensor Signal Sensitivity {#8-dot-2-sensor-signal-sensitivity}


#### 8.2.1 Sensing Element {#8-dot-2-dot-1-sensing-element}


#### 8.2.2 Converting an Impedance into an Electric Signal {#8-dot-2-dot-2-converting-an-impedance-into-an-electric-signal}


##### 8.2.2.1 Wheatstone Bridge {#8-dot-2-dot-2-dot-1-wheatstone-bridge}


#### 8.2.3 Electronic Interconnection of Sensitive Signals {#8-dot-2-dot-3-electronic-interconnection-of-sensitive-signals}


##### 8.2.3.1 Magnetic Disturbances {#8-dot-2-dot-3-dot-1-magnetic-disturbances}


##### 8.2.3.2 Capacitive Disturbances {#8-dot-2-dot-3-dot-2-capacitive-disturbances}


##### 8.2.3.3 Ground Loops {#8-dot-2-dot-3-dot-3-ground-loops}


### 8.3 Signal Conditioning {#8-dot-3-signal-conditioning}


#### 8.3.1 Instrumentation Amplifier {#8-dot-3-dot-1-instrumentation-amplifier}


#### 8.3.2 Filtering and Modulation {#8-dot-3-dot-2-filtering-and-modulation}


##### 8.3.2.1 AM with Square Wave Carrier {#8-dot-3-dot-2-dot-1-am-with-square-wave-carrier}


##### 8.3.2.2 AM with Sinusoidal Carrier {#8-dot-3-dot-2-dot-2-am-with-sinusoidal-carrier}


### 8.4 Signal Processing {#8-dot-4-signal-processing}


#### 8.4.1 Schmitt Trigger {#8-dot-4-dot-1-schmitt-trigger}


#### 8.4.2 Digital Representation of Measurement Data {#8-dot-4-dot-2-digital-representation-of-measurement-data}


##### 8.4.2.1 Gray Code {#8-dot-4-dot-2-dot-1-gray-code}


##### 8.4.2.2 Sampling of Analogue Values {#8-dot-4-dot-2-dot-2-sampling-of-analogue-values}


##### 8.4.2.3 Nyquist-Shannon Theorem {#8-dot-4-dot-2-dot-3-nyquist-shannon-theorem}


##### 8.4.2.4 Filtering to Prevent Aliasing {#8-dot-4-dot-2-dot-4-filtering-to-prevent-aliasing}


#### 8.4.3 Analogue-to-Digital Converters {#8-dot-4-dot-3-analogue-to-digital-converters}


##### 8.4.3.1 Dual-Slope ADC {#8-dot-4-dot-3-dot-1-dual-slope-adc}


##### 8.4.3.2 Successive-Approximation ADC {#8-dot-4-dot-3-dot-2-successive-approximation-adc}


##### 8.4.3.3 Sigma-Delta ADC {#8-dot-4-dot-3-dot-3-sigma-delta-adc}


##### 8.4.3.4 ADC Latency in a Feedback Loop {#8-dot-4-dot-3-dot-4-adc-latency-in-a-feedback-loop}


#### 8.4.4 Connecting the Less Sensitive Elements {#8-dot-4-dot-4-connecting-the-less-sensitive-elements}


##### 8.4.4.1 Characteristic Impedance {#8-dot-4-dot-4-dot-1-characteristic-impedance}


##### 8.4.4.2 Non-Galvanic Connection {#8-dot-4-dot-4-dot-2-non-galvanic-connection}


### 8.5 Short-Range Motion Sensors {#8-dot-5-short-range-motion-sensors}


#### 8.5.1 Optical Sensors {#8-dot-5-dot-1-optical-sensors}


##### 8.5.1.1 Position Sensitive Detectors {#8-dot-5-dot-1-dot-1-position-sensitive-detectors}


##### 8.5.1.2 Optical Deflectometer {#8-dot-5-dot-1-dot-2-optical-deflectometer}


#### 8.5.2 Capacitive Position Sensors {#8-dot-5-dot-2-capacitive-position-sensors}


##### 8.5.2.1 Linearising by Differential Measurement {#8-dot-5-dot-2-dot-1-linearising-by-differential-measurement}


##### 8.5.2.2 Accuracy Limits and Improvements {#8-dot-5-dot-2-dot-2-accuracy-limits-and-improvements}


##### 8.5.2.3 Sensing to Conductive Moving Plate {#8-dot-5-dot-2-dot-3-sensing-to-conductive-moving-plate}


#### 8.5.3 Inductive Position Sensors {#8-dot-5-dot-3-inductive-position-sensors}


##### 8.5.3.1 Linear Variable Differential Transformer {#8-dot-5-dot-3-dot-1-linear-variable-differential-transformer}


##### 8.5.3.2 Eddy-Current Sensors {#8-dot-5-dot-3-dot-2-eddy-current-sensors}


#### 8.5.4 Pneumatic Proximity Sensor or Air-Gage {#8-dot-5-dot-4-pneumatic-proximity-sensor-or-air-gage}


### 8.6 Measurement of Mechanical Dynamics {#8-dot-6-measurement-of-mechanical-dynamics}


#### 8.6.1 Measurement of Force and Strain {#8-dot-6-dot-1-measurement-of-force-and-strain}


##### 8.6.1.1 Strain Gages {#8-dot-6-dot-1-dot-1-strain-gages}


##### 8.6.1.2 Fibre Bragg Grating Strain Measurement {#8-dot-6-dot-1-dot-2-fibre-bragg-grating-strain-measurement}


#### 8.6.2 Velocity Measurement {#8-dot-6-dot-2-velocity-measurement}


##### 8.6.2.1 Geophone {#8-dot-6-dot-2-dot-1-geophone}


#### 8.6.3 Accelerometers {#8-dot-6-dot-3-accelerometers}


##### 8.6.3.1 Closed-Loop Feedback Accelerometer {#8-dot-6-dot-3-dot-1-closed-loop-feedback-accelerometer}


##### 8.6.3.2 Piezoelectric Accelerometer {#8-dot-6-dot-3-dot-2-piezoelectric-accelerometer}


##### 8.6.3.3 MEMS Accelerometer {#8-dot-6-dot-3-dot-3-mems-accelerometer}


### 8.7 Optical Long-Range Incremental Position Sensors {#8-dot-7-optical-long-range-incremental-position-sensors}


#### 8.7.1 Linear Optical Encoders {#8-dot-7-dot-1-linear-optical-encoders}


##### 8.7.1.1 Interpolation {#8-dot-7-dot-1-dot-1-interpolation}


##### 8.7.1.2 Vernier Resolution Enhancement {#8-dot-7-dot-1-dot-2-vernier-resolution-enhancement}


##### 8.7.1.3 Interferometric Optical Encoder {#8-dot-7-dot-1-dot-3-interferometric-optical-encoder}


##### 8.7.1.4 Concluding Remarks on Linear Encoders {#8-dot-7-dot-1-dot-4-concluding-remarks-on-linear-encoders}


#### 8.7.2 Laser Interferometer Measurement Systems {#8-dot-7-dot-2-laser-interferometer-measurement-systems}


##### 8.7.2.1 Homodyne Distance Interferometry {#8-dot-7-dot-2-dot-1-homodyne-distance-interferometry}


##### 8.7.2.2 Heterodyne Distance Interferometry {#8-dot-7-dot-2-dot-2-heterodyne-distance-interferometry}


##### 8.7.2.3 Measurement Uncertainty {#8-dot-7-dot-2-dot-3-measurement-uncertainty}


##### 8.7.2.4 Configurations {#8-dot-7-dot-2-dot-4-configurations}


##### 8.7.2.5 Multi-Axis Laser Interferometers {#8-dot-7-dot-2-dot-5-multi-axis-laser-interferometers}


#### 8.7.3 Mechanical Aspects {#8-dot-7-dot-3-mechanical-aspects}


##### 8.7.3.1 Abbe Error {#8-dot-7-dot-3-dot-1-abbe-error}


## 9 Precision Positioning in Wafer Scanners {#9-precision-positioning-in-wafer-scanners}


### Introduction {#introduction}


### 9.1 The Waferscanner {#9-dot-1-the-waferscanner}


#### 9.1.1 Requirements on Precision {#9-dot-1-dot-1-requirements-on-precision}


### 9.2 Dynamic Architecture {#9-dot-2-dynamic-architecture}


#### 9.2.1 Balance Masses {#9-dot-2-dot-1-balance-masses}


#### 9.2.2 Vibration Isolation {#9-dot-2-dot-2-vibration-isolation}


##### 9.2.2.1 Eigendynamics of the Sensitive Parts {#9-dot-2-dot-2-dot-1-eigendynamics-of-the-sensitive-parts}


### 9.3 Zero-Stiffness Stage Actuation {#9-dot-3-zero-stiffness-stage-actuation}


#### 9.3.1 Waferstage Actuation Concept {#9-dot-3-dot-1-waferstage-actuation-concept}


##### 9.3.1.1 Waferstepper Long-Range Lorentz Actuator {#9-dot-3-dot-1-dot-1-waferstepper-long-range-lorentz-actuator}


##### 9.3.1.2 Multi-Axis Positioning {#9-dot-3-dot-1-dot-2-multi-axis-positioning}


##### 9.3.1.3 Long- and Short-Stroke Actuation {#9-dot-3-dot-1-dot-3-long-and-short-stroke-actuation}


#### 9.3.2 Full Magnetic Levitation {#9-dot-3-dot-2-full-magnetic-levitation}


#### 9.3.3 Acceleration Limits of Reticle Stage {#9-dot-3-dot-3-acceleration-limits-of-reticle-stage}


### 9.4 Position Measurement {#9-dot-4-position-measurement}


#### 9.4.1 Alignment Sensor {#9-dot-4-dot-1-alignment-sensor}


#### 9.4.2 Keeping the Wafer in Focus {#9-dot-4-dot-2-keeping-the-wafer-in-focus}


#### 9.4.3 Dual-Stage Measurement and Exposure {#9-dot-4-dot-3-dual-stage-measurement-and-exposure}


#### 9.4.4 Long-Range Incremental Measurement System {#9-dot-4-dot-4-long-range-incremental-measurement-system}


##### 9.4.4.1 Real-Time Metrology Loop {#9-dot-4-dot-4-dot-1-real-time-metrology-loop}


### 9.5 Motion Control {#9-dot-5-motion-control}


#### 9.5.1 Feedforward and Feedback Control {#9-dot-5-dot-1-feedforward-and-feedback-control}


##### 9.5.1.1 Thermal, The Final Frontier {#9-dot-5-dot-1-dot-1-thermal-the-final-frontier}


#### 9.5.2 The Mass Dilemma {#9-dot-5-dot-2-the-mass-dilemma}

> A reduced mass requires improved system dynamics that enable a higher control bandwidth to compensate for the increase sensitivity for external vibrations.


### 9.6 Future Developments in IC Lithography {#9-dot-6-future-developments-in-ic-lithography}


### 9.7 Main Design Rules for Precision {#9-dot-7-main-design-rules-for-precision}


## Bibliography {#bibliography}

<a id="orga3e0eb9"></a>Schmidt, R Munnig, Georg Schitter, and Adrian Rankers. 2020. _The Design of High Performance Mechatronics - Third Revised Edition_. Ios Press.
